@@ -20,7 +20,6 @@ from pydantic import BaseModel
 from .pipeline.grep import GrepTool
 from .pipeline.glob import GlobTool
 from .pipeline.read import ReadTool
-from .pipeline.keyword_extractor import KeywordExtractor
 from .pipeline.base import PipelineConfig, CandidateMatch
 
 
@@ -44,7 +43,7 @@ class SearchResponse(BaseModel):
     results: List[SearchResult]
     total_candidates: int
     query: str
-    execution_time_ms: float
+    execution_time_ms: Optional[float] = None
     extracted_keywords: Optional[Dict[str, Any]] = None
     tools_used: Optional[List[str]] = None
     overall_reasoning: Optional[str] = None
@@ -98,7 +97,7 @@ class GrebClient:
             base_url: API base URL (required or set GREB_API_URL env var)
             timeout: Request timeout in seconds
             max_retries: Maximum number of retry attempts
-            max_grep_results: Max results from local grep (default: 1500)
+            max_grep_results: Max results from local grep (default: 1000)
         """
         self.api_key = api_key or os.getenv("GREB_API_KEY")
         if not self.api_key:
@@ -118,7 +117,7 @@ class GrebClient:
         self.max_retries = max_retries
         
         # Initialize LOCAL search tools (run on user's machine)
-        max_grep = max_grep_results or int(os.getenv("MAX_GREP_RESULTS", "1500"))
+        max_grep = max_grep_results or int(os.getenv("MAX_GREP_RESULTS", "10000"))
         max_glob = int(os.getenv("MAX_GLOB_RESULTS", "50"))
         read_max_size = int(os.getenv("READ_MAX_FILE_SIZE", "5048576"))
         self.grep_tool = GrepTool(max_results=max_grep)
@@ -171,115 +170,48 @@ class GrebClient:
             )
             ```
         """
-        # Step 1: Call server to extract keywords using Cerebras
-        keyword_response = self.client.post(
-            "/v1/extract-keywords",
-            json={"query": query}
-        )
-        keyword_response.raise_for_status()
-        keyword_data = keyword_response.json()
-        
-        keywords = keyword_data.get("search_terms", []) or keyword_data.get("primary_terms", [])
-        if not keywords:
-            raise ValueError(f"Server failed to extract keywords from query: {query}")
-        
-        # Step 2: Run full orchestrator pipeline LOCALLY on user's machine
-        # This includes parallel grep, glob (for <10K files), read tool, turn logic, etc.
+        # Use orchestrator pipeline - all custom logic removed
         from .pipeline.orchestrator import PipelineOrchestrator
         from .pipeline.base import PipelineConfig
-        
-        # Create local orchestrator config (no Cerebras key needed for local search)
-        local_config = PipelineConfig(
-            cerebras_api_key="",  # Not used locally
-            max_grep_results=self.grep_tool.max_results,
-            max_glob_results=self.glob_tool.max_results,
-            top_k_results=max_results or 10
-        )
-        
-        local_orchestrator = PipelineOrchestrator(local_config)
-        
-        # Run LOCAL search with full pipeline (parallel grep, turn logic, glob, read)
-        # But only up to candidate collection - don't rerank locally
+
         search_dir = os.path.abspath(directory) if directory else os.getcwd()
-        
-        print(f"Running local search pipeline in {search_dir}")
-        
-        # Use orchestrator's internal methods for local search
-        # This gives us all the parallel grep, turn logic, file counting, etc.
-        from .pipeline.base import ExtractedKeywords
-        extracted_keywords = ExtractedKeywords(
-            primary_terms=keyword_data.get("primary_terms", []),
-            search_terms=keywords,
-            file_patterns=file_patterns or keyword_data.get("file_patterns", []),
-            intent=keyword_data.get("intent", query)
+      
+        # Create orchestrator config - server handles all Cerebras calls
+        orchestrator_config = PipelineConfig(
+            cerebras_api_key="",  # Server handles Cerebras
+            max_grep_results=int(os.getenv("MAX_GREP_RESULTS", "10000")),
+            max_glob_results=int(os.getenv("MAX_GLOB_RESULTS", "10")),
+            top_k_results=int(os.getenv("TOP_K_RESULTS", "10"))
         )
-        
-        # Run local parallel searches with orchestrator logic
-        all_spans = []
-        search_dir_path = search_dir
-        
-        # Count files for strategy
-        file_count = sum(1 for _ in os.walk(search_dir))
-        use_glob = file_count < 10000
-        
-        # Execute parallel grep searches (from orchestrator)
-        from concurrent.futures import ThreadPoolExecutor, as_completed
-        MAX_PARALLEL_SEARCHES = 8
-        
-        with ThreadPoolExecutor(max_workers=MAX_PARALLEL_SEARCHES) as executor:
-            futures = []
-            search_terms = extracted_keywords.search_terms[:MAX_PARALLEL_SEARCHES]
-            
-            for term in search_terms:
-                future = executor.submit(
-                    local_orchestrator.grep_tool.grep,
-                    pattern=term,
-                    path=search_dir_path,
-                    file_pattern=file_patterns[0] if file_patterns else "*",
-                    context_lines=3,
-                    case_sensitive=False
-                )
-                futures.append((term, future))
-            
-            # Collect results
-            for term, future in futures:
-                try:
-                    result = future.result(timeout=30)
-                    if result and result.get("matches"):
-                        for match in result["matches"]:
-                            all_spans.append({
-                                "path": match.get("path", ""),
-                                "line_number": match.get("line_number", 0),
-                                "content": match.get("line", ""),
-                                "context": match.get("context", []),
-                                "score": 0.0
-                            })
-                except Exception as e:
-                    print(f"Grep failed for '{term}': {e}")
-        
-        # Deduplicate
-        unique_candidates = {}
-        for span in all_spans:
-            key = (span["path"], span["line_number"])
-            if key not in unique_candidates:
-                unique_candidates[key] = span
-        
-        candidates = list(unique_candidates.values())
-        
-        # Step 3: Send candidates to API for Cerebras reranking
-        rerank_request = {
-            "query": query,
-            "candidates": candidates,
-            "max_results": max_results
-        }
-        
-        response = self.client.post(
-            "/v1/rerank",
-            json=rerank_request
+
+        orchestrator = PipelineOrchestrator(orchestrator_config)
+
+        # Use main search method - orchestrator handles keyword extraction and reranking via server
+        response = orchestrator.search(
+            query=query,
+            directory=search_dir,
+            file_patterns=file_patterns,
+            max_results=max_results,
+            server_client=self.client
+        )
+
+        # Convert RankedResult objects to SearchResult objects
+        search_results = [
+            SearchResult(
+                path=result.path,
+                score=result.score,
+                highlights=result.highlights,
+                summary=result.summary
+            )
+            for result in response.results
+        ]
+
+        return SearchResponse(
+            results=search_results,
+            total_candidates=response.total_candidates,
+            query=response.query,
+            overall_reasoning=response.overall_reasoning
         )
-        response.raise_for_status()
-        
-        return SearchResponse(**response.json())
     
     def chat(
         self,
