@@ -7,6 +7,7 @@ from __future__ import annotations
 import os
 from pathlib import Path
 from typing import List, Optional, Dict, Tuple, Union
+from concurrent.futures import ThreadPoolExecutor, as_completed
 
 from .base import FileSpan, CandidateMatch
 
@@ -120,12 +121,12 @@ class ReadTool:
         if end_line is not None:
             end_idx = min(len(lines), end_line)
         else:
-            end_idx = len(lines)
+            end_idx = min(len(lines), start_line + window_size + 1 if start_line is not None and window_size is not None else len(lines))
 
         # Apply window size if specified
         if window_size is not None and start_line is not None:
             start_idx = max(0, start_idx - window_size)
-            end_idx = min(len(lines), end_idx + window_size)
+            end_idx = min(len(lines), start_line + window_size + 1)
 
         # Extract the relevant lines
         selected_lines = lines[start_idx:end_idx]
@@ -151,6 +152,8 @@ class ReadTool:
         """
         Convert CandidateMatch objects to FileSpan objects with context.
 
+        OPTIMIZED: Uses concurrent file reading for better performance.
+
         Args:
             candidates: List of CandidateMatch objects
             window_size: Number of context lines around each match
@@ -159,37 +162,82 @@ class ReadTool:
         Returns:
             List of FileSpan objects
         """
-        spans = []
-        processed_files = set()
         # Environment variable is primary source, passed parameter is override only if explicitly provided
         window_size = window_size if window_size is not None else int(os.getenv('CONTEXT_WINDOW_SIZE', '3'))
-        max_spans = max_spans if max_spans is not None else int(os.getenv('READ_MAX_SPANS', '50'))
+        max_spans = max_spans if max_spans is not None else int(os.getenv('READ_MAX_SPANS', '500'))
+
+        # Filter and limit candidates first
+        unique_candidates = []
+        seen_files = set()
+
+        for candidate in candidates:
+            if len(unique_candidates) >= max_spans:
+                break
 
-        for candidate in candidates[:max_spans]:
             file_path = candidate.path
-
-            # Skip files we've already processed (avoid duplicates)
-            if file_path in processed_files:
+            # Skip duplicate files
+            if file_path in seen_files:
                 continue
-
             # Skip ignored files
             if self._should_ignore_file(file_path):
                 continue
 
-            try:
-                span = self.read_file(
-                    file_path=file_path,
-                    start_line=candidate.line_number,
-                    end_line=candidate.line_number,
-                    window_size=window_size
-                )
-                spans.append(span)
-                processed_files.add(file_path)
-            except (FileNotFoundError, ValueError):
-                # Skip files that can't be read
-                continue
+            unique_candidates.append(candidate)
+            seen_files.add(file_path)
 
-        return spans
+        # Use concurrent file reading for better performance
+        spans = []
+        # OPTIMIZED: Dynamic scaling based on CPU cores for I/O-bound tasks
+        cpu_count = os.cpu_count() or 4
+        # For I/O-bound file reading, use 4x CPU cores but respect configured limits
+        optimal_workers = min(cpu_count * 4, int(os.getenv('READ_MAX_WORKERS', '64')))
+        max_workers = min(len(unique_candidates), optimal_workers)
+
+        if max_workers == 0:
+            return spans
+
+        with ThreadPoolExecutor(max_workers=max_workers) as executor:
+            # Submit all file reading tasks
+            future_to_candidate = {
+                executor.submit(
+                    self._read_candidate_file,
+                    candidate,
+                    window_size
+                ): candidate
+                for candidate in unique_candidates
+            }
+
+            # Collect results as they complete
+            for future in as_completed(future_to_candidate):
+                try:
+                    span = future.result()
+                    if span:
+                        spans.append(span)
+                except (FileNotFoundError, ValueError, Exception):
+                    # Skip files that can't be read
+                    continue
+
+        # Return spans in original order for consistency
+        return spans[:max_spans]
+
+    def _read_candidate_file(
+        self,
+        candidate: CandidateMatch,
+        window_size: int
+    ) -> Optional[FileSpan]:
+        """
+        Helper method to read a single candidate file.
+        Separated for better concurrency handling.
+        """
+        try:
+            return self.read_file(
+                file_path=candidate.path,
+                start_line=candidate.line_number,
+                end_line=None,
+                window_size=window_size
+            )
+        except (FileNotFoundError, ValueError, Exception):
+            return None
 
     def read_multiple_files(
         self,
