@@ -89,12 +89,12 @@ class RerankTool:
         ]
 
         try:
-            # Use structured output for reliable parsing
-            response = self.client.chat.completions.create(
-                model=self.config.cerebras_model,
-                messages=messages,
-                temperature=self.config.rerank_temperature,
-                response_format={
+            # Build API call parameters
+            api_params = {
+                "model": self.config.cerebras_model,
+                "messages": messages,
+                "temperature": self.config.rerank_temperature,
+                "response_format": {
                     "type": "json_schema",
                     "json_schema": {
                         "name": "rerank_results",
@@ -131,7 +131,13 @@ class RerankTool:
                         }
                     }
                 }
-            )
+            }
+
+            # Add reasoning_effort parameter only for gpt-oss-120b model
+            if self.config.cerebras_model == "gpt-oss-120b":
+                api_params["reasoning_effort"] = self.config.reasoning_effort
+
+            response = self.client.chat.completions.create(**api_params)
 
             # Track token usage from reranking with messages and span data
             token_tracker.track_reranking(response, messages, span_data)
@@ -163,7 +169,7 @@ Use your intelligence to determine relevance based on semantic meaning, context,
 
     def _get_user_prompt(self, query: str, span_data: List[Dict], top_k: int) -> str:
         """Get the user prompt for reranking."""
-        spans_text = json.dumps(span_data, indent=2)
+        spans_text = json.dumps(span_data, separators=(',', ':'))
 
         return f"""Search Query: "{query}"
 
@@ -293,12 +299,12 @@ Rank based on what would most help solve the user's actual problem."""
         ]
 
         try:
-            # Use structured output for reliable parsing with enhanced context
-            response = self.client.chat.completions.create(
-                model=self.config.cerebras_model,
-                messages=messages,
-                temperature=self.config.rerank_temperature,
-                response_format={
+            # Build API call parameters
+            api_params = {
+                "model": self.config.cerebras_model,
+                "messages": messages,
+                "temperature": self.config.rerank_temperature,
+                "response_format": {
                     "type": "json_schema",
                     "json_schema": {
                         "name": "enhanced_rerank_results",
@@ -336,7 +342,13 @@ Rank based on what would most help solve the user's actual problem."""
                         }
                     }
                 }
-            )
+            }
+
+            # Add reasoning_effort parameter only for gpt-oss-120b model
+            if self.config.cerebras_model == "gpt-oss-120b":
+                api_params["reasoning_effort"] = self.config.reasoning_effort
+
+            response = self.client.chat.completions.create(**api_params)
 
             # Track token usage from enhanced reranking with messages and span data
             token_tracker.track_enhanced_reranking(response, messages, span_data)
@@ -392,7 +404,7 @@ Focus on the user's actual intent and what they're trying to accomplish.
 Return the top {top_k} results that best address the user's original request.
 
 Code Snippets:
-{json.dumps(span_data, indent=2)}"""
+{json.dumps(span_data, separators=(',', ':'))}"""
 
     def _convert_to_enhanced_ranked_results(
         self,
@@ -482,12 +494,19 @@ Code Snippets:
             }
         ]
 
-        reasoning_response = self.client.chat.completions.create(
-            model=self.config.cerebras_model,
-            messages=reasoning_messages,
-            temperature=0,
-            max_tokens=200
-        )
+        # Build API call parameters for reasoning
+        reasoning_params = {
+            "model": self.config.cerebras_model,
+            "messages": reasoning_messages,
+            "temperature": 0,
+            "max_tokens": 200
+        }
+
+        # Add reasoning_effort parameter only for gpt-oss-120b model
+        if self.config.cerebras_model == "gpt-oss-120b":
+            reasoning_params["reasoning_effort"] = self.config.reasoning_effort
+
+        reasoning_response = self.client.chat.completions.create(**reasoning_params)
 
         # Track token usage from reasoning with messages
         token_tracker.track_reasoning(reasoning_response, reasoning_messages)
